@@ -7,9 +7,7 @@ from numpy.ma import masked as numpy_ma_masked
 from numpy.ma import nomask as numpy_ma_nomask
 
 from . import mpi_on
-if mpi_on:
-    from . import mpi_size
-#--- End: if
+from . import mpi_size
 
 #platform = sys.platform
 #if platform == 'darwin':
@@ -97,18 +95,21 @@ _TOTAL_MEMORY = float(virtual_memory().total)
 CONSTANTS = {'RTOL'                  : sys.float_info.epsilon,
              'ATOL'                  : sys.float_info.epsilon,
              'TEMPDIR'               : gettempdir(),
-             'MINNCFM'               : 10,
              'OF_FRACTION'           : 0.5,
              'TOTAL_MEMORY'          : _TOTAL_MEMORY,
-             'CHUNKSIZE'             : _TOTAL_MEMORY * 0.01,
-             'FREE_MEMORY_FACTOR'    : mpi_size if mpi_on else 1,
+             'FREE_MEMORY_FACTOR'    : 0.1,
+             'WORKSPACE_FACTOR_1'    : 2.0,
+             'WORKSPACE_FACTOR_2'    : 8.0,
              'REGRID_LOGGING'        : False,
              'COLLAPSE_PARALLEL_MODE': 0,
              'RELAXED_IDENTITIES'    : False,
              'IGNORE_IDENTITIES'     : False,
              }
 
-CONSTANTS['FM_THRESHOLD'] = CONSTANTS['MINNCFM']*CONSTANTS['CHUNKSIZE']
+CONSTANTS['FM_THRESHOLD'] = CONSTANTS['FREE_MEMORY_FACTOR'] * CONSTANTS['TOTAL_MEMORY']
+
+CONSTANTS['CHUNKSIZE'] = (CONSTANTS['FM_THRESHOLD'] /
+                          (mpi_size * CONSTANTS['WORKSPACE_FACTOR_1'] + CONSTANTS['WORKSPACE_FACTOR_2']))
 
 masked = numpy_ma_masked
 nomask = numpy_ma_nomask
