@@ -54,6 +54,7 @@ from .          import __version__, __file__
 from .constants import CONSTANTS, _file_to_fh
 
 from . import mpi_on
+from . import mpi_size
 
 # Are we running on GNU/Linux?
 _linux = system() == 'Linux'
@@ -115,8 +116,6 @@ longer required.
         #--- End: for
 
         free_bytes = free_KiB * 1024
-        if mpi_on:
-            free_bytes /= CONSTANTS['FREE_MEMORY_FACTOR']
 
         return free_bytes
     #--- End: def
@@ -140,11 +139,7 @@ The amount of available physical memory.
 96496240.0
 
 '''
-        free_bytes = float(virtual_memory().available)
-        if mpi_on:
-            free_bytes /= CONSTANTS['FREE_MEMORY_FACTOR']
-        #--- End: if
-        return free_bytes
+        return float(virtual_memory().available)
     #--- End: def
 #--- End: if
 
@@ -172,15 +167,110 @@ Free memory = 88.2727928162 GiB
     return _free_memory()
 #--- End: def
 
+def _WORKSPACE_FACTOR_1():
+    '''The value of workspace factor 1 used in calculating the upper limit
+to the chunksize given the free memory factor.
+
+:Returns:
+
+    out: `float`
+        workspace factor 1
+
+    '''
+    return CONSTANTS['WORKSPACE_FACTOR_1']
+#--- End: def
+
+def _WORKSPACE_FACTOR_2():
+    '''The value of workspace factor 2 used in calculating the upper limit
+to the chunksize given the free memory factor.
+
+:Returns:
+
+    out: `float`
+        workspace factor 2
+
+    '''
+    return CONSTANTS['WORKSPACE_FACTOR_2']
+#--- End: def
+
+def _FREE_MEMORY_FACTOR(*args):
+    '''Set the fraction of memory kept free as a temporary
+    workspace. Users should set the free memory factor through
+    cf.SET_PERFORMANCE so that the upper limit to the chunksize is
+    recalculated appropriately. The free memory factor must be a
+    sensible value between zero and one. If no arguments are passed
+    the existing free memory factor is returned.
+
+:Parameters:
+
+    free_memory_factor: `float`
+        The fraction of memory kept free as a temporary workspace.
+
+:Returns:
+
+    out: `float`
+         The previous value of the free memory factor.
+
+    '''
+    old = CONSTANTS['FREE_MEMORY_FACTOR']
+    if args:
+        free_memory_factor = float(args[0])
+        if free_memory_factor <= 0.0 or free_memory_factor >= 1.0:
+            raise ValueError('Free memory factor must be between 0.0 and 1.0 not inclusive')
+        #--- End: if
+        CONSTANTS['FREE_MEMORY_FACTOR'] = free_memory_factor
+        CONSTANTS['FM_THRESHOLD'] = free_memory_factor * TOTAL_MEMORY()
+    #--- End: if
+    return old
+#--- End: def
+
+def CHUNKSIZE(*args):
+    '''Set the chunksize used by LAMA for partitioning the data
+array. This must be smaller than an upper limit determined by the free
+memory factor, which is the fraction of memory kept free as a
+temporary workspace, otherwise an error is raised. If called with None
+as the argument then the chunksize is set to its upper limit. If called
+without any arguments the existing chunksize is returned.
+
+The upper limit to the chunksize is given by:
+
+upper_chunksize = ((free_memory_factor * TOTAL_MEMORY()) / ((mpi_size
+                   * _WORKSPACE_FACTOR_1()) + _WORKSPACE_FACTOR_2()))
+
+:Parameters:
+
+    chunksize: `float`, optional
+        The chunksize in bytes.
+
+:Returns:
+
+    out: `float`
+        The previous value of the chunksize in bytes.
+
+    '''
+    old = CONSTANTS['CHUNKSIZE']
+    if args:
+        upper_chunksize = (FM_THRESHOLD() / ((mpi_size *
+                                              _WORKSPACE_FACTOR_1()) +
+                                             _WORKSPACE_FACTOR_2()))
+        if args[0] is None:
+            CONSTANTS['CHUNKSIZE'] = upper_chunksize
+        else:
+            chunksize = float(args[0])
+            if chunksize > upper_chunksize:
+                raise ValueError('Specified chunk size is too large for given free memory factor')
+            elif chunksize <= 0:
+                raise ValueError('Chunk size must be positive')
+            #--- End: if
+            CONSTANTS['CHUNKSIZE'] = chunksize
+        #--- End: if
+    #--- End: if
+    return old
+#--- End: def
+
 def FM_THRESHOLD():
     '''The amount of memory which is kept free as a temporary work space.
 
-This is the chunk size (returned and set by `cf.CHUNKSIZE`) multiplied
-by the number of chunks of memory to be kept free (returned and set by
-`cf.MINNCFM`).
-
-.. seealso:: `cf.CHUNKSIZE`, `cf.MINNCFM`
-
 :Returns:
 
     out: `float`
@@ -190,106 +280,61 @@ by the number of chunks of memory to be kept free (returned and set by
 
 >>> cf.FM_THRESHOLD()
 10000000000.0
->>> old = cf.MINNCFM(2*cf.MINNCFM())
->>> cf.FM_THRESHOLD()
-20000000000.0
 
     '''
     return CONSTANTS['FM_THRESHOLD']
 #--- End: def
 
-def CHUNKSIZE(*size):
-    '''
-
-The memory chunk size in bytes for data storage and processing.
-
-When setting the chunk size, the amount of minimum amount of memory to
-be kept free as a temporary work space is also updated.
-
-.. seealso:: `cf.MINNCFM`
-
-:Examples 1:
-
->>> current_chunksize = cf.CHUNKSIZE()
+def SET_PERFORMANCE(chunksize=None, free_memory_factor=None):
+    '''Tune performance of parallelisation by setting chunksize and free
+memory factor. By just providing the chunksize it can be changed to a
+smaller value than an upper limit, which is determined by the existing
+free memory factor. If just the free memory factor is provided then
+the chunksize is set to the corresponding upper limit. Note that the
+free memory factor is the fraction of memory kept free as a temporary
+workspace and must be a sensible value between zero and one. If both
+arguments are provided then the free memory factor is changed first
+and then the chunksize is set provided it is consistent with the new
+free memory value. If any of the arguments is invalid then an error is
+raised and no parameters are changed. When called with no aruments the
+existing values of the parameters are returned in a tuple.
 
 :Parameters:
 
-    size: `int`, optional
-        The new chunk size in bytes. The default is to not change the
-        current value.
+    chunksize: `float`, optional
+        The size in bytes of a chunk used by LAMA to partition the
+        data array.
+
+    free_memory_factor: `float`, optional
+        The fraction of memory to keep free as a temporary workspace.
 
 :Returns:
 
-    out: `float`
-        The value prior to the change, or the current value if no new
-        value was specified.
-
-:Examples 2:
-
->>> cf.CHUNKSIZE()
-57095864.32
->>> old = cf.CHUNKSIZE(2**30)
->>> cf.CHUNKSIZE(old)
-1073741824
->>> cf.CHUNKSIZE()
-57095864.32
-
-'''
-    old = CONSTANTS['CHUNKSIZE']
-    if size:
-        size = size[0]
-        CONSTANTS['CHUNKSIZE']    = size
-        CONSTANTS['FM_THRESHOLD'] = MINNCFM() * size
+    out: `tuple`
+        A tuple of the previous chunksize and free_memory_factor.
 
+    '''
+    old = CHUNKSIZE(), _FREE_MEMORY_FACTOR()
+    if free_memory_factor is None:
+        if chunksize is not None:
+            CHUNKSIZE(chunksize)
+        #--- End: if
+    else:
+        _FREE_MEMORY_FACTOR(free_memory_factor)
+        try:
+            CHUNKSIZE(chunksize)
+        except ValueError:
+            _FREE_MEMORY_FACTOR(old[1])
+            raise
+        #--- End: try
+    #--- End: if
     return old
 #--- End: def
 
 def TOTAL_MEMORY():
     '''
-'''
-    return CONSTANTS['TOTAL_MEMORY']
-#--- End: def
-
-def MINNCFM(*arg):
     '''
-
-The number of chunks of memory to be kept free as a temporary work
-space.
-
-A chunk of memory is the amount of memory set by `cf.CHUNKSIZE`.
- 
-.. seealso:: `cf.CHUNKSIZE`
-
-:Parameters:
-
-    arg : int, optional
-        The number of chunks to be kept free as a temporary work
-        space. The default is to not change the current value.
-
-:Returns:
-
-    out: `int`
-        The value prior to the change, or the current value if no new
-        value was specified.
-
-:Examples:
-
->>> cf.MINNCFM()
-10
->>> old = cf.MINNCFM(20)
->>> cf.MINNCFM(old)
-20
->>> f.MINNCFM()
-10
-
-'''
-    old = CONSTANTS['MINNCFM']
-    if arg:
-        minncfm = arg[0]
-        CONSTANTS['MINNCFM']      = minncfm
-        CONSTANTS['FM_THRESHOLD'] = minncfm * CHUNKSIZE()
-
-    return old
+    return CONSTANTS['TOTAL_MEMORY']
 #--- End: def
 
 def TEMPDIR(*arg):
@@ -485,39 +530,6 @@ possible modes:
     return old
 #--- End: def
 
-def FREE_MEMORY_FACTOR(*arg):
-    '''The factor to divide the free memory by if MPI is on. Usually
-this is the number of PEs. If MPI is not on this is ignored.
-
-:Parameters:
-
-    arg: `int`, optional
-        The new value.
-
-:Returns:
-
-    out: `int`
-        The value prior to the change, or the current value if no new
-        value was specified.
-
-:Examples:
-
->>> cf.FREE_MEMORY_FACTOR()
-4
->>> cf.FREE_MEMORY_FACTOR(1)
-4
->>> cf.FREE_MEMORY_FACTOR()
-1
-
-    '''
-    old = CONSTANTS['FREE_MEMORY_FACTOR']
-    if arg:
-        CONSTANTS['FREE_MEMORY_FACTOR'] = arg[0]
-    #--- End: if
-
-    return old
-#--- End: def
-
 def RELAXED_IDENTITIES(*arg):
     '''
 
