@@ -21,7 +21,7 @@ regridding through ESMPY and the associated utility methods.
     """
     
     def __init__(self, srcfield, dstfield, srcfracfield, dstfracfield,
-                 method='conservative', ignore_degenerate=False):
+                 method='conservative_1st', ignore_degenerate=False):
         """Creates a handle for regridding fields from a source grid to a
 destination grid that can then be used by the run_regridding method.
 
@@ -44,28 +44,27 @@ destination grid that can then be used by the run_regridding method.
         contributes to conservative regridding.
 
     method: `str`ing, optional
-        By default the regridding method is set to 'conservative'. In
-        this case first-order conservative regridding is used. If it
-        is set to 'bilinear' then multilinear interpolation is used.
-        If it is set to 'patch' then higher-order patch recovery is
-        used.  If it is set to 'nearest_stod' then nearest neighbor
-        interpolation is used where each destination point is mapped
-        to the closest source point. A given source point may map to
-        multiple destination points, but no destination point will
-        receive input from more than one source point. If it is set to
-        'nearest_dtos' then nearest neighbor interpolation is used
-        where each source point is mapped to the closest destination
-        point. A given destination point may receive input from
-        multiple source points, but no source point will map to more
-        than one destination point.
+
+        By default the regridding method is set to
+        'conservative_1st'. In this case or if it is set to
+        'conservative' first-order conservative regridding is used. If
+        it is set to 'conservative_2nd' second order conservative
+        regridding is used. If it is set to 'bilinear' then
+        (multi)linear interpolation is used.  If it is set to 'patch'
+        then higher-order patch recovery is used.  If it is set to
+        'nearest_stod' then nearest source to destination
+        interpolation is used. If it is set to 'nearest_dtos' then
+        nearest destination to source interpolation is used.
 
     ignore_degenerate: `bool`, optional
         Whether to check for degenerate points.
 
         """
         # create a handle to the regridding method
-        if method == 'conservative':
+        if method in ('conservative', 'conservative_1st'):
             regrid_method = ESMF.RegridMethod.CONSERVE
+        elif method == 'conservative_2nd':
+            regrid_method = ESMF.RegridMethod.CONSERVE_2ND
         elif method == 'bilinear':
             regrid_method = ESMF.RegridMethod.BILINEAR
         elif method == 'patch':
