@@ -8,8 +8,6 @@ if mpi_on:
     from . import mpi_rank
 #--- End: if
 
-from .functions import FREE_MEMORY_FACTOR
-
 def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
@@ -305,13 +303,9 @@ which have equal values across all input fields.
             raise RuntimeError('write expects either 1 unique filename or as many as there are PEs')
         #--- End: if
 
-        if write_only_on_pe0:
-            if mpi_rank == 0:
-                old_free_memory_factor = FREE_MEMORY_FACTOR(1)
-            else:
-                mpi_comm.Barrier()
-                return
-            #--- End: if
+        if write_only_on_pe0 and not mpi_rank == 0:
+            mpi_comm.Barrier()
+            return
         #--- End: if
     #--- End: if
 
@@ -330,7 +324,6 @@ which have equal values across all input fields.
     #--- End: if
 
     if mpi_on and write_only_on_pe0:
-        FREE_MEMORY_FACTOR(old_free_memory_factor)
         mpi_comm.Barrier()
     #--- End: if
 #--- End: def
