@@ -21,7 +21,9 @@ class FieldTest(unittest.TestCase):
         self.test_only = []
 #        self.test_only = ['NOTHING!!!!!!']
 #        self.test_only = ['test_COLLAPSE_CLIMATOLOGICAL_TIME']
-
+#        self.test_only = ['test_COLLAPSE']
+#        self.test_only = ['test_COLLAPSE_GROUP_OPTIONS']
+        
     def test_COLLAPSE_CLIMATOLOGICAL_TIME(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -137,6 +139,58 @@ class FieldTest(unittest.TestCase):
 
         #--- End: for    
 
+    def test_COLLAPSE_GROUP_OPTIONS(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        cf.CHUNKSIZE(self.original_chunksize)
+    
+        for chunksize in self.chunk_sizes[0:2]:
+            cf.CHUNKSIZE(chunksize)
+
+            f = cf.read(self.filename4)[0]
+
+            g = f.collapse('T: mean', group=cf.M(12)                  , group_span=cf.Y())
+            g = f.collapse('T: mean', group=cf.M(12, month=12)        , group_span=cf.Y())
+            g = f.collapse('T: mean', group=cf.M(12, day=16)          , group_span=cf.Y())
+            g = f.collapse('T: mean', group=cf.M(12, month=11, day=27), group_span=cf.Y())
+            g = f.collapse('T: mean', group=cf.M(12, month= 6, day=27), group_span=cf.Y())
+
+            g = f.collapse('T: mean', group=cf.M(5, month=12),
+                           group_span=cf.M(5), group_contiguous=1)
+            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+                           group_span=cf.M(5), group_contiguous=1)
+            g = f.collapse('T: mean', group=cf.M(5, month=12),
+                           group_span=cf.M(5), group_contiguous=2)
+            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+                           group_span=cf.M(5), group_contiguous=2)
+
+            g = f.collapse('T: mean', group=cf.M(5, month=12),
+                           group_contiguous=1)
+            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+                           group_contiguous=1)
+            g = f.collapse('T: mean', group=cf.M(5, month=12),
+                           group_contiguous=2)
+            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+                           group_contiguous=2)
+
+            g = f.collapse('T: mean within years time: minimum over years',
+                           within_years=cf.M(3), group_span=True)
+            
+            g = f.collapse('T: mean within years time: minimum over years',
+                           within_years=cf.seasons(), group_span=cf.M(3))
+            
+#            g = f[::2].collapse('T: mean', group=cf.M(5, month=12),
+#                                group_span=cf.M(5),group_contiguous=1)
+#            print g
+#            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+#                           group_contiguous=1)
+#            g = f.collapse('T: mean', group=cf.M(5, month=12),
+#                           group_contiguous=2)
+#            g = f.collapse('T: mean', group=cf.M(5, month= 3),
+#                           group_contiguous=2)
+        #--- End: for
+        
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
      
